summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorDave Davenport <qball@gmpclient.org>2017-06-02 16:25:47 +0200
committerDave Davenport <qball@gmpclient.org>2017-06-02 16:25:47 +0200
commit9915857a2ec4d13d83a963252264394fb7ce3f28 (patch)
treec4b7ee0efcb6946195919a585809e7c3e2d5a96a /include
parent7352f1c2bacb1da3dc603f88da54176ddc5f9107 (diff)
Change Distance struct to RofiDistance.
Diffstat (limited to 'include')
-rw-r--r--include/theme.h20
-rw-r--r--include/widgets/scrollbar.h2
2 files changed, 11 insertions, 11 deletions
diff --git a/include/widgets/scrollbar.h b/include/widgets/scrollbar.h
index 7bf97cc1..2806bc3f 100644
--- a/include/widgets/scrollbar.h
+++ b/include/widgets/scrollbar.h
@@ -46,7 +46,7 @@ typedef struct _scrollbar
unsigned int length;
unsigned int pos;
unsigned int pos_length;
- Distance width;
+ RofiDistance width;
} scrollbar;
/**
diff --git a/include/theme.h b/include/theme.h
index 101f7d5d..6fafce73 100644
--- a/include/theme.h
+++ b/include/theme.h
@@ -85,7 +85,7 @@ typedef struct
RofiPixelUnit type;
/** Style of the line */
RofiLineStyle style;
-} Distance;
+} RofiDistance;
/**
* Type of orientation.
@@ -144,10 +144,10 @@ typedef struct
*/
typedef struct
{
- Distance top;
- Distance right;
- Distance bottom;
- Distance left;
+ RofiDistance top;
+ RofiDistance right;
+ RofiDistance bottom;
+ RofiDistance left;
} Padding;
/**
@@ -300,7 +300,7 @@ void rofi_theme_widget_add_properties ( ThemeWidget *widget, GHashTable *table )
*
* @returns The distance value of this property for this widget.
*/
-Distance rofi_theme_get_distance ( const widget *widget, const char *property, int def );
+RofiDistance rofi_theme_get_distance ( const widget *widget, const char *property, int def );
/**
* @param widget The widget to query
* @param property The property to query.
@@ -310,7 +310,7 @@ Distance rofi_theme_get_distance ( const widget *widget, const char *property, i
*
* @returns The distance value of this property for this widget.
*/
-Distance rofi_theme_get_distance_exact ( const widget *widget, const char *property, int def );
+RofiDistance rofi_theme_get_distance_exact ( const widget *widget, const char *property, int def );
/**
* @param widget The widget to query
@@ -424,17 +424,17 @@ ThemeHighlight rofi_theme_get_highlight ( widget *widget, const char *property,
* @param d The distance handle.
* @param ori The orientation.
*
* Convert Distance into pixels.
* @returns the number of pixels this distance represents.
*/
-int distance_get_pixel ( Distance d, Orientation ori );
+int distance_get_pixel ( RofiDistance d, Orientation ori );
/**
* @param d The distance handle.
* @param draw The cairo drawable.
*
* Set linestyle.
*/
-void distance_get_linestyle ( Distance d, cairo_t *draw );
+void distance_get_linestyle ( RofiDistance d, cairo_t *draw );
/**
* Low-level functions.
@@ -424,17 +424,17 @@ ThemeHighlight rofi_theme_get_highlight ( widget *widget, const char *property,
* @param ori The orientation.
*
- * Convert Distance into pixels.
+ * Convert RofiDistance into pixels.
* @returns the number of pixels this distance represents.
*/